# models


## Result model

::: pyrcrack.models.Result
    :docstring:
    :members:


## Wifi Interface model

::: pyrcrack.models.Interface
    :docstring:
    :members:



## Wifi Interfaces List

::: pyrcrack.models.Interfaces
    :docstring:
    :members:


## AP's Client

::: pyrcrack.models.Client
    :docstring:
    :members:
